import java.util.*;

/**
 * An agent in the Game of Life.
 * The agent has only two states.
 * 
 * @author David J. Barnes
 * @version 2009.04.21
 */
public class Agent
{
    // The agent's state.
    private boolean state;
    // The agent's neighbours.
    private List<Agent> neighbours;

    /**
     * Set the initial state to be false/0
     */
    public Agent()
    {
        this(false);
    }
    
    /**
     * Set the initial state.
     * @param initialState The initial state
     */
    public Agent(boolean initialState)
    {
        state = initialState;
        neighbours = new ArrayList<Agent>(0);
    }

    /**
     * Get the state of this agent.
     * @return The state.
     */
    public boolean getState()
    {
        return state;
    }
    
    /**
     * Set the state of this agent.
     * @param The state.
     */
    public void setState(boolean state)
    {
        this.state = state;
    }
    
    /**
     * Determine this actor's next state, based on the
     * state of its neighbours.
     * @return The next state.
     */
    public boolean getNextState()
    {
        int setCount = 0;
        for(Agent n : neighbours) {
            if(n.getState()) {
                setCount++;
            }
        }
        if(setCount < 2 || setCount > 3) {
            return false;
        }
        else if(state) {
            return true;
        }
        else if(setCount == 2) {
            return false;
        }
        else {
            return true;
        }
    }
    
    /**
     * Receive the list of neighbouring agents.
     * @param neighbours Neighbouring agents.
     */
    void setNeighbours(List<Agent> neighbours)
    {
        this.neighbours = neighbours;
    }
    
    
}
