package simulation;

/**
 * An implementation of Gibson and Bruck's First Reaction variation
 * of Gillespie's SSA.
 * 
 * Gibson, M., Bruck, J.: Efficient exact stochastic simulation of chemical systems
 * with many species and many channels.
 * Journal of Physical Chemistry 104, 1876-1889 (2000)
 *
 * @author David J. Barnes (d.j.barnes@kent.ac.uk)
 *
 */
public class Main 
{
	/**
	 * Program starting point.
	 * Stopping time and output sampling rate may be specified via
	 * program parameters.
	 * @param args Optional stop time and output sampling rate in steps.
	 */
	public static void main(String[] args)
	{
		double stopTime = 200;
		int samplingRate = 1;
		if(args.length > 0) {
			stopTime = Double.parseDouble(args[0]);
			if(args.length > 1) {
				samplingRate = Integer.parseInt(args[1]);
			}
		}
		Model model = new Model(stopTime, samplingRate);
		model.run();
	}
}
