package simulation;

/**
 * A product that is delayed before production is complete.
 * 
 * @author djb
 *
 */
public class DelayedProduct extends Product
{
	// The delay before production.
	private double delay;
	// The model.
	private Model model;

	/**
	 * Create a delayed product
	 * @param molecule The product.
	 * @param multiplicity Multiplicity of the product.
	 * @param delay Length of the delay.
	 * @param model The model.
	 */
	public DelayedProduct(Molecule molecule, int multiplicity, double delay, Model model)
	{
		super(molecule, multiplicity);
		this.delay = delay;
		this.model = model;
	}
	
	/**
	 * Create a delayed product with multiplicity of 1.
	 * @param molecule The product.
	 * @param delay Length of the delay.
	 * @param model The model.
	 */
	public DelayedProduct(Molecule molecule, double delay, Model model)
	{
		this(molecule, 1, delay, model);
	}
	
	/**
	 * Schedule production for a later time according to the delay. 
	 */
	public void produce()
	{
		// Support non-constant delays by calling getDelay rather than
		// using delay directly.
		double productionTime = model.getTime() + getDelay();
		model.scheduleDelayedProduction(
					new PendingProduct(getMolecule(), getMultiplicity(), productionTime));
	}
	
	/**
	 * Return the delay time for this product.
	 * Override for non-constant delays.
	 * @return The delay time for this product.
	 */
	protected double getDelay()
	{
		return delay;
	}

}
